package com.kaajjo.libresudoku.ui.theme

import androidx.compose.material3.ColorScheme
import androidx.compose.material3.darkColorScheme
import androidx.compose.material3.lightColorScheme
import androidx.compose.ui.graphics.Color

class AppColorScheme {
    fun getTheme(appTheme: AppTheme, dark: Boolean = false): ColorScheme {
        return when (appTheme) {
            AppTheme.Green -> if (dark) greenDark else greenLight
            AppTheme.Blue -> if (dark) blueDark else blueLight
            AppTheme.Peach -> if (dark) pinkDark else pinkLight
            AppTheme.Yellow -> if (dark) yellowDark else yellowLight
            AppTheme.Lavender -> if (dark) lavenderDark else lavenderLight
            AppTheme.BlackAndWhite -> if (dark) blackAndWhiteDark else blackAndWhiteLight
        }
    }

    private val greenLight = lightColorScheme(
        primary = Color(0xFF1F6D19),
        onPrimary = Color(0xFFFFFFFF),
        primaryContainer = Color(0xFFA4F791),
        onPrimaryContainer = Color(0xFF002200),
        secondary = Color(0xFF54634E),
        onSecondary = Color(0xFFFFFFFF),
        secondaryContainer = Color(0xFFD7E8CD),
        onSecondaryContainer = Color(0xFF121F0E),
        tertiary = Color(0xFF386569),
        onTertiary = Color(0xFFFFFFFF),
        tertiaryContainer = Color(0xFFBCEBEE),
        onTertiaryContainer = Color(0xFF002022),
        error = Color(0xFFBA1A1A),
        errorContainer = Color(0xFFFFDAD6),
        onError = Color(0xFFFFFFFF),
        onErrorContainer = Color(0xFF410002),
        background = Color(0xFFFCFDF6),
        onBackground = Color(0xFF1A1C18),
        surface = Color(0xFFFCFDF6),
        onSurface = Color(0xFF1A1C18),
        surfaceVariant = Color(0xFFDFE4D8),
        onSurfaceVariant = Color(0xFF43483F),
        outline = Color(0xFF73796E),
        inverseOnSurface = Color(0xFFF1F1EB),
        inverseSurface = Color(0xFF2F312D),
        inversePrimary = Color(0xFF89DA78),
        surfaceTint = Color(0xFF1D461A),
    )

    private val greenDark = darkColorScheme(
        primary = Color(0xFF89DA78),
        onPrimary = Color(0xFF003A01),
        primaryContainer = Color(0xFF005302),
        onPrimaryContainer = Color(0xFFA4F791),
        secondary = Color(0xFFBBCBB2),
        onSecondary = Color(0xFF263422),
        secondaryContainer = Color(0xFF3C4B37),
        onSecondaryContainer = Color(0xFFD7E8CD),
        tertiary = Color(0xFFA0CFD2),
        onTertiary = Color(0xFF00373A),
        tertiaryContainer = Color(0xFF1E4D51),
        onTertiaryContainer = Color(0xFFBCEBEE),
        error = Color(0xFFFFB4AB),
        errorContainer = Color(0xFF93000A),
        onError = Color(0xFF690005),
        onErrorContainer = Color(0xFFFFDAD6),
        background = Color(0xFF1A1C18),
        onBackground = Color(0xFFE2E3DD),
        surface = Color(0xFF1A1C18),
        onSurface = Color(0xFFE2E3DD),
        surfaceVariant = Color(0xFF43483F),
        onSurfaceVariant = Color(0xFFC3C8BC),
        outline = Color(0xFF8D9387),
        inverseOnSurface = Color(0xFF1A1C18),
        inverseSurface = Color(0xFFE2E3DD),
        inversePrimary = Color(0xFF1F6D19),
        surfaceTint = Color(0xFF55944F)
    )

    private val pinkLight = lightColorScheme(
        primary = Color(0xFF9C4144),
        onPrimary = Color(0xFFFFFFFF),
        primaryContainer = Color(0xFFFFDAD9),
        onPrimaryContainer = Color(0xFF410008),
        secondary = Color(0xFF775656),
        onSecondary = Color(0xFFFFFFFF),
        secondaryContainer = Color(0xFFFFDAD9),
        onSecondaryContainer = Color(0xFF2C1515),
        tertiary = Color(0xFF755A2F),
        onTertiary = Color(0xFFFFFFFF),
        tertiaryContainer = Color(0xFFFFDEAD),
        onTertiaryContainer = Color(0xFF281900),
        error = Color(0xFFBA1A1A),
        errorContainer = Color(0xFFFFDAD6),
        onError = Color(0xFFFFFFFF),
        onErrorContainer = Color(0xFF410002),
        background = Color(0xFFFFFBFF),
        onBackground = Color(0xFF201A1A),
        surface = Color(0xFFFFFBFF),
        onSurface = Color(0xFF201A1A),
        surfaceVariant = Color(0xFFF4DDDC),
        onSurfaceVariant = Color(0xFF524343),
        outline = Color(0xFF857372),
        inverseOnSurface = Color(0xFFFBEEED),
        inverseSurface = Color(0xFF362F2E),
        inversePrimary = Color(0xFFFFB3B2),
        surfaceTint = Color(0xFF351617),
    )

    private val pinkDark = darkColorScheme(
        primary = Color(0xFFD89896),
        onPrimary = Color(0xFF5F131A),
        primaryContainer = Color(0xFF7E2A2E),
        onPrimaryContainer = Color(0xFFFFDAD9),
        secondary = Color(0xFFE6BDBC),
        onSecondary = Color(0xFF442929),
        secondaryContainer = Color(0xFF5D3F3F),
        onSecondaryContainer = Color(0xFFFFDAD9),
        tertiary = Color(0xFFE4C18D),
        onTertiary = Color(0xFF422C05),
        tertiaryContainer = Color(0xFF5B431A),
        onTertiaryContainer = Color(0xFFFFDEAD),
        error = Color(0xFFFFB4AB),
        errorContainer = Color(0xFF93000A),
        onError = Color(0xFF690005),
        onErrorContainer = Color(0xFFFFDAD6),
        background = Color(0xFF201A1A),
        onBackground = Color(0xFFECE0DF),
        surface = Color(0xFF201A1A),
        onSurface = Color(0xFFECE0DF),
        surfaceVariant = Color(0xFF524343),
        onSurfaceVariant = Color(0xFFD7C1C1),
        outline = Color(0xFFA08C8C),
        inverseOnSurface = Color(0xFF201A1A),
        inverseSurface = Color(0xFFECE0DF),
        inversePrimary = Color(0xFF9C4144),
        surfaceTint = Color(0xFF463030),
    )

    private val yellowLight = lightColorScheme(
        primary = Color(0xFF5A6400),
        onPrimary = Color(0xFFFFFFFF),
        primaryContainer = Color(0xFFDDEB77),
        onPrimaryContainer = Color(0xFF1A1E00),
        secondary = Color(0xFF5E6144),
        onSecondary = Color(0xFFFFFFFF),
        secondaryContainer = Color(0xFFBEC097),
        onSecondaryContainer = Color(0xFF1B1D07),
        tertiary = Color(0xFF3B665B),
        onTertiary = Color(0xFFFFFFFF),
        tertiaryContainer = Color(0xFFBEECDD),
        onTertiaryContainer = Color(0xFF002019),
        error = Color(0xFFBA1A1A),
        errorContainer = Color(0xFFFFDAD6),
        onError = Color(0xFFFFFFFF),
        onErrorContainer = Color(0xFF410002),
        background = Color(0xFFF6F7ED),
        onBackground = Color(0xFF1C1C17),
        surface = Color(0xFFF6F7ED),
        onSurface = Color(0xFF1C1C17),
        surfaceVariant = Color(0xFFE4E3D2),
        onSurfaceVariant = Color(0xFF47483B),
        outline = Color(0xFF78786A),
        inverseOnSurface = Color(0xFFF3F1E8),
        inverseSurface = Color(0xFF31312B),
        inversePrimary = Color(0xFFC1CF5F),
        surfaceTint = Color(0xFF5A6400),
    )

    private val yellowDark = darkColorScheme(
        primary = Color(0xFFD1CA53),
        onPrimary = Color(0xFF343200),
        primaryContainer = Color(0xFF4C4900),
        onPrimaryContainer = Color(0xFFEEE76C),
        secondary = Color(0xFFCCC8A4),
        onSecondary = Color(0xFF333118),
        secondaryContainer = Color(0xFF4A482C),
        onSecondaryContainer = Color(0xFFE8E4BE),
        tertiary = Color(0xFFA5D0BA),
        onTertiary = Color(0xFF0D3728),
        tertiaryContainer = Color(0xFF274E3E),
        onTertiaryContainer = Color(0xFFC1ECD6),
        error = Color(0xFFFFB4AB),
        errorContainer = Color(0xFF93000A),
        onError = Color(0xFF690005),
        onErrorContainer = Color(0xFFFFDAD6),
        background = Color(0xFF1C1C16),
        onBackground = Color(0xFFE6E2D9),
        surface = Color(0xFF1C1C16),
        onSurface = Color(0xFFE6E2D9),
        surfaceVariant = Color(0xFF49473A),
        onSurfaceVariant = Color(0xFFCAC7B5),
        outline = Color(0xFF949181),
        inverseOnSurface = Color(0xFF1C1C16),
        inverseSurface = Color(0xFFE6E2D9),
        inversePrimary = Color(0xFF656100),
        surfaceTint = Color(0xFF3F3D19)
    )

    private val lavenderLight = lightColorScheme(
        primary = Color(0xFF7F4894),
        onPrimary = Color(0xFFFFFFFF),
        primaryContainer = Color(0xFFF8D8FF),
        onPrimaryContainer = Color(0xFF320046),
        secondary = Color(0xFF69596D),
        onSecondary = Color(0xFFFFFFFF),
        secondaryContainer = Color(0xFFF1DCF3),
        onSecondaryContainer = Color(0xFF231728),
        tertiary = Color(0xFF81524F),
        onTertiary = Color(0xFFFFFFFF),
        tertiaryContainer = Color(0xFFFFDAD8),
        onTertiaryContainer = Color(0xFF331110),
        error = Color(0xFFBA1A1A),
        errorContainer = Color(0xFFFFDAD6),
        onError = Color(0xFFFFFFFF),
        onErrorContainer = Color(0xFF410002),
        background = Color(0xFFFFFBFF),
        onBackground = Color(0xFF1E1B1E),
        surface = Color(0xFFFFFBFF),
        onSurface = Color(0xFF1E1B1E),
        surfaceVariant = Color(0xFFEBDFE9),
        onSurfaceVariant = Color(0xFF4C444D),
        outline = Color(0xFF7D747D),
        inverseOnSurface = Color(0xFFF7EFF3),
        inverseSurface = Color(0xFF332F33),
        inversePrimary = Color(0xFFECB1FF),
        surfaceTint = Color(0xFF321D3A),
    )

    private val lavenderDark = darkColorScheme(
        primary = Color(0xFFECB1FF),
        onPrimary = Color(0xFF4C1662),
        primaryContainer = Color(0xFF65307A),
        onPrimaryContainer = Color(0xFFF8D8FF),
        secondary = Color(0xFFD5C0D7),
        onSecondary = Color(0xFF392C3D),
        secondaryContainer = Color(0xFF514254),
        onSecondaryContainer = Color(0xFFF1DCF3),
        tertiary = Color(0xFFF5B7B4),
        onTertiary = Color(0xFF4C2524),
        tertiaryContainer = Color(0xFF663B39),
        onTertiaryContainer = Color(0xFFFFDAD8),
        error = Color(0xFFFFB4AB),
        errorContainer = Color(0xFF93000A),
        onError = Color(0xFF690005),
        onErrorContainer = Color(0xFFFFDAD6),
        background = Color(0xFF1E1B1E),
        onBackground = Color(0xFFE8E0E5),
        surface = Color(0xFF1E1B1E),
        onSurface = Color(0xFFE8E0E5),
        surfaceVariant = Color(0xFF4C444D),
        onSurfaceVariant = Color(0xFFCEC3CD),
        outline = Color(0xFF988E97),
        inverseOnSurface = Color(0xFF1E1B1E),
        inverseSurface = Color(0xFFE8E0E5),
        inversePrimary = Color(0xFF7F4894),
        surfaceTint = Color(0xFF47354D),
    )

    private val blackAndWhiteLight = lightColorScheme(
        primary = Color(0xFF000000),
        onPrimary = Color(0xFFFFFFFF),
        primaryContainer = Color(0xFFD8D8D8),
        onPrimaryContainer = Color(0xFF0C0C0C),
        secondary = Color(0xFF000000),
        onSecondary = Color(0xFFE0E0E0),
        secondaryContainer = Color(0xFFCCCCCC),
        onSecondaryContainer = Color(0xFF202020),
        tertiary = Color(0xFFFFFFFF),
        onTertiary = Color(0xFF2E2E2E),
        tertiaryContainer = Color(0xFF047291),
        onTertiaryContainer = Color(0xFF331110),
        error = Color(0xFFBA1A1A),
        errorContainer = Color(0xFFFFDAD6),
        onError = Color(0xFFFFFFFF),
        onErrorContainer = Color(0xFF410002),
        background = Color(0xFFFFFFFF),
        onBackground = Color(0xFF1A1A1A),
        surface = Color(0xFFFFFFFF),
        onSurface = Color(0xFF1E1B1E),
        surfaceVariant = Color(0xFFE9E9E9),
        onSurfaceVariant = Color(0xFF4D4D4D),
        outline = Color(0xFF7D747D),
        inverseOnSurface = Color(0xFFF1F1F1),
        inverseSurface = Color(0xFF313131),
        inversePrimary = Color(0xFFEEEEEE),
        surfaceTint = Color(0xFF000000),
    )

    private val blackAndWhiteDark = darkColorScheme(
        primary = Color(0xFFFFFFFF),
        onPrimary = Color(0xFF313131),
        primaryContainer = Color(0xFF4D4D4D),
        onPrimaryContainer = Color(0xFFD1D1D1),
        secondary = Color(0xFFE6E6E6),
        onSecondary = Color(0xFF161616),
        secondaryContainer = Color(0xFF4D4D4D),
        onSecondaryContainer = Color(0xFFE4E4E4),
        tertiary = Color(0xFF4A849E),
        onTertiary = Color(0xFFDDDDDD),
        tertiaryContainer = Color(0xFF047291),
        onTertiaryContainer = Color(0xFF331110),
        error = Color(0xFFBA1A1A),
        errorContainer = Color(0xFFFFDAD6),
        onError = Color(0xFFFFFFFF),
        onErrorContainer = Color(0xFF410002),
        background = Color(0xFF181818),
        onBackground = Color(0xFFF1F1F1),
        surface = Color(0xFF181818),
        onSurface = Color(0xFFF1F1F1),
        surfaceVariant = Color(0xFF3C3C3C),
        onSurfaceVariant = Color(0xFFCFCFCF),
        outline = Color(0xFF7D747D),
        inverseOnSurface = Color(0xFF252525),
        inverseSurface = Color(0xFFC0C0C0),
        inversePrimary = Color(0xFFE0E0E0),
        surfaceTint = Color(0xFFFFFFFF),
    )

    private val blueLight = lightColorScheme(
        primary = Color(0xFF085EB0),
        onPrimary = Color(0xFFFFFFFF),
        primaryContainer = Color(0xFFD5E3FF),
        onPrimaryContainer = Color(0xFF001C3B),
        secondary = Color(0xFF555F71),
        onSecondary = Color(0xFFFFFFFF),
        secondaryContainer = Color(0xFFD9E3F8),
        onSecondaryContainer = Color(0xFF121C2B),
        tertiary = Color(0xFF6E5676),
        onTertiary = Color(0xFFFFFFFF),
        tertiaryContainer = Color(0xFFF8D8FE),
        onTertiaryContainer = Color(0xFF27132F),
        error = Color(0xFFBA1A1A),
        errorContainer = Color(0xFFFFDAD6),
        onError = Color(0xFFFFFFFF),
        onErrorContainer = Color(0xFF410002),
        background = Color(0xFFFDFBFF),
        onBackground = Color(0xFF1A1C1E),
        inverseOnSurface = Color(0xFFF1F0F4),
        inverseSurface = Color(0xFF2F3033),
        inversePrimary = Color(0xFFA7C8FF),
        surfaceTint = Color(0xFF085EB0),
        outlineVariant = Color(0xFFC4C6CF),
        scrim = Color(0xFF000000),
        surface = Color(0xFFFDFBFF),
        onSurface = Color(0xFF1A1C1E)
    )

    private val blueDark = darkColorScheme(
        primary = Color(0xFFA7C8FF),
        onPrimary = Color(0xFF003060),
        primaryContainer = Color(0xFF004787),
        onPrimaryContainer = Color(0xFFD5E3FF),
        secondary = Color(0xFFBDC7DC),
        onSecondary = Color(0xFF273141),
        secondaryContainer = Color(0xFF3D4758),
        onSecondaryContainer = Color(0xFFD9E3F8),
        tertiary = Color(0xFFDBBDE2),
        onTertiary = Color(0xFF3E2845),
        tertiaryContainer = Color(0xFF553F5D),
        onTertiaryContainer = Color(0xFFF8D8FE),
        error = Color(0xFFFFB4AB),
        errorContainer = Color(0xFF93000A),
        onError = Color(0xFF690005),
        onErrorContainer = Color(0xFFFFDAD6),
        background = Color(0xFF1A1C1E),
        onBackground = Color(0xFFE3E2E6),
        outline = Color(0xFF8D9199),
        inverseOnSurface = Color(0xFF1A1C1E),
        inverseSurface = Color(0xFFE3E2E6),
        inversePrimary = Color(0xFF085EB0),
        surfaceTint = Color(0xFFA7C8FF),
        outlineVariant = Color(0xFF43474E),
        scrim = Color(0xFF000000),
        surface = Color(0xFF1A1C1E),
        onSurface = Color(0xFFC7C6CA),
        surfaceVariant = Color(0xFF43474E),
        onSurfaceVariant = Color(0xFFC4C6CF)
    )
}

enum class AppTheme {
    Green,
    Blue,
    Peach,
    Yellow,
    Lavender,
    BlackAndWhite
}